#ifndef _EFL_CANVAS_ANIMATION_GROUP_SEQUENTIAL_EO_H_
#define _EFL_CANVAS_ANIMATION_GROUP_SEQUENTIAL_EO_H_

#ifndef _EFL_CANVAS_ANIMATION_GROUP_SEQUENTIAL_EO_CLASS_TYPE
#define _EFL_CANVAS_ANIMATION_GROUP_SEQUENTIAL_EO_CLASS_TYPE

typedef Eo Efl_Canvas_Animation_Group_Sequential;

#endif

#ifndef _EFL_CANVAS_ANIMATION_GROUP_SEQUENTIAL_EO_TYPES
#define _EFL_CANVAS_ANIMATION_GROUP_SEQUENTIAL_EO_TYPES


#endif
#ifdef EFL_BETA_API_SUPPORT
/** Efl group sequential animation class
 *
 * @ingroup Efl_Canvas_Animation_Group_Sequential
 */
#define EFL_CANVAS_ANIMATION_GROUP_SEQUENTIAL_CLASS efl_canvas_animation_group_sequential_class_get()

EWAPI const Efl_Class *efl_canvas_animation_group_sequential_class_get(void);
#endif /* EFL_BETA_API_SUPPORT */

#endif
